@@ -5,6 +5,7 @@ from scipy.io.wavfile import read
 import torch
 import numpy as np
 
+
 def convto2205(ori_audio_path):
     file_name = os.path.basename(ori_audio_path)
     dir_name = os.path.dirname(ori_audio_path)
@@ -26,6 +27,7 @@ def torch_load_audio(audio_path, norm=True, sr=None):
         
     data = torch.FloatTensor(data.astype(np.float32))
     
+    return data, sampling_rate
 
-    
-    return data, sampling_rate
\ No newline at end of file
+def resample_index(index, input_sr, output_sr):
+    return index / input_sr * output_sr
\ No newline at end of file
